package liviu.tudor.convertor.provider;

import javax.microedition.lcdui.Image;

public interface ConvertProvider 
{
    /**
     * This returns the name of the convertor, which will be displayed in the menu.
     * 
     * @return name of this convertor
     */
    public String getName();
    
    /**
     * This returns an image that will be shown in the menu, next to the name of this convertor
     * 
     * @return Image for this convertor, or null if none, in which case the caller will use
     * a default image.
     */
    public Image getImage();
    
    /**
     * Returns all the names of the fields for which we can provide conversions.
     * Each such field will have a label with the returned name and a text area next to
     * it to allow the user to input data.
     * When data is entered in one of the fields, the application will call {@link #setFieldValue(int, double) setFieldValue()}
     * and pass the data entered by the user. The convertor then will have to compute all the values
     * for the other fields based on this and return the values.
     * 
     * @return List of all the input field names
     */
    public String[] getFieldNames();
    
    /**
     * Returns all the values of the fields, following the conversion made after the user has called
     * {@link #setFieldValue(int, double) setFieldValue()}. The returned array should be in fact the
     * same array returned by {@link #setFieldValue(int, double) setFieldValue()}.
     * 
     * @return List of all the converted values
     */
    public double[] getFieldValues();
    
    /**
     * This function gets called when the user has input a value in one of the text fields.
     * 
     * @param index Index of the field the user has edited
     * @param value Value the user has input
     * @return List of all the converted values
     * @throws IllegalArgumentException if the value passed is not acceptable
     */
    public double[] setFieldValue( int index, double value ) throws IllegalArgumentException;
    
    /**
     * This function will provide a short description of the service the provider offers.
     * 
     * @return Small description of the service offered.
     */
    public String getInfo();
}
