package liviu.tudor.convertor.provider;

/**
 * This class converts distances
 * 
 * @author Liviu Tudor
 */
public class DistanceConvertor extends ConvertProviderAdapter 
{
    /**
     * Default constructor.
     * In here we initialize all our measure units for distance.
     * The reference is going to be the meter (m).
     */
    public DistanceConvertor()
    {
        addField( "Picometer",          1.0E-12 );
        addField( "Nanometer",          1.0E-9 );
        addField( "Micrometer",         0.000001 );
        addField( "Millimeters (mm)",   0.001 );
        addField( "Centimeters (cm)",   0.01 );
        addField( "Meters (m)",         1, true );
        addField( "Dekameter",          10 );
        addField( "Hectometer",         100 );
        addField( "Kilometers (km)",    1000 );
        addField( "Inches",             0.0254 );
        addField( "Feet",               0.3048 );
        addField( "Yards",              0.9144 );
        addField( "Miles",              1609.344 );
        addField( "Nautical Miles",     1852 );
        addField( "League",             4828.0417 );
        addField( "Nautical League",    5556 );
        addField( "Microinch",          2.54E-8 );
        addField( "Yoctometer",         1.0E-24 );
        addField( "Zeptometer",         1.0E-21 );
        addField( "Attometer",          1.0E-18 );
        addField( "Femtometer",         1.0E-15 );
        addField( "Tenthmeter",         1.0E-10 );
        addField( "Myriameter",         10000.0 );
        addField( "Megameter",          1000000.0 );
        addField( "Gigameter",          1000000000.0 );
        addField( "Terameter",          1000000000000.0 ); 
        addField( "Petameter",          1000000000000000.0 );
        addField( "Exameter",           1000000000000000000.0 );
        addField( "Zeptameter",         1.0E+21 );
        addField( "Yoltameter",         1.0E+24 );
    }
    
    /**
     * Return the name of our convertor -- <i>Distance</i>
     */
    public String getName() 
    {
        return "Distance";
    }

    /**
     * Return our convertor image name -- in this case, a ruler
     */
    public String getImageName() 
    {
        return "/img/ruler.png";
    }
    
    public String getInfo()
    {
        return "Provides distance conversions to and from: mm, cm, m, km, inches, feet, yards, miles and nautical miles";
    }

    /**
     * Make sure that the value is right.
     * The only restriction here is that the value should be greater than or equal to zero (0)
     */
    protected void checkValue(int index, double value) throws IllegalArgumentException 
    {
        if( value < 0 )
            throw new IllegalArgumentException( "Only positive values are converted!" );
    }
}
