package liviu.tudor.convertor.provider;

/**
 * This class converts volumes
 * 
 * @author Liviu Tudor
 */
public class VolumeConvertor extends ConvertProviderAdapter 
{
    /**
     * Constructor.
     * Here we initialize all of our values we can convert.
     * The reference value is litre.
     */
    public VolumeConvertor() 
    {
        addField( "Milliliter",             0.001 );
        addField( "Centiliter",             0.01 );
        addField( "Deciliter",              0.1 );
        addField( "Hectoliter",             100 );
        addField( "Kiloliter",              1000 );
        addField( "Cubic meter",            1000 );
        addField( "Cubic centimeter",       0.001 );
        addField( "Cubic decimeter",        1 );
        addField( "Liter",                  1, true );
        addField( "Ounce (UK)",             0.028413063 );
        addField( "Ounce (US)",             0.02957353 );
        addField( "Pint (UK)",              0.56826125 );
        addField( "Pint (US)",              0.550610475 );
        addField( "Quarts (UK)",            1.1365225 );
        addField( "Quarts (US)",            0.94635295 );
        addField( "Gallon (UK)",            4.54609 );
        addField( "Gallon (US)",            3.78541 );
        addField( "Cup",                    0.23659 );
        addField( "Cubic foot",             28.316846712 );
        addField( "Cubic inch",             0.016387064 );
        addField( "Dram",                   0.003696691 );
        addField( "Barrel (UK)",            163.65924 );
        addField( "Barrel (US, federal)",   117.3477658 );
        addField( "Barrel (US, liquid)",    119.2404717 );
        addField( "Barrel (US, petroleum)", 158.9872956 );
        addField( "Bucket (UK)",            18.18436 );
        addField( "Bucket (US)",            18.927059 );
    }

    /**
     * Return our convertor image name -- in this case, a cube
     */
    public String getImageName() 
    {
        return "/img/volume.png";
    }

    /**
     * Check the value.
     * In this case we simply want a positive value
     */
    protected void checkValue(int index, double value) throws IllegalArgumentException 
    {
        if( value < 0 )
            throw new IllegalArgumentException( "Only positive values are converted!" );
    }

    /**
     * Name this convertor <i>Volume</i>
     */
    public String getName() 
    {
        return "Volume";
    }

    public String getInfo() 
    {
        return "Provides volume conversions to and from: litres, fluid ounces, quarts, gallons, cups etc.";
    }
}
